==> 1.1.1.tar.gz: lib/model/apple_verify_receipt_request.dart <==
part of forestvpn_api.api;

class AppleVerifyReceiptRequest {
  /* The latest Base64-encoded transaction receipt. */
  String receipt = null;
  AppleVerifyReceiptRequest();

  @override
  String toString() {
    return 'AppleVerifyReceiptRequest[receipt=$receipt, ]';
  }

  AppleVerifyReceiptRequest.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    receipt = json['receipt'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (receipt != null)
      json['receipt'] = receipt;
    return json;
  }

  static List<AppleVerifyReceiptRequest> listFromJson(List<dynamic> json) {
    return json == null ? List<AppleVerifyReceiptRequest>() : json.map((value) => AppleVerifyReceiptRequest.fromJson(value)).toList();
  }

  static Map<String, AppleVerifyReceiptRequest> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, AppleVerifyReceiptRequest>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = AppleVerifyReceiptRequest.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of AppleVerifyReceiptRequest-objects as value to a dart map
  static Map<String, List<AppleVerifyReceiptRequest>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<AppleVerifyReceiptRequest>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = AppleVerifyReceiptRequest.listFromJson(value);
       });
     }
     return map;
  }
}

==> 1.2.1.tar.gz: lib/model/apple_verify_receipt_request.dart <==
part of forestvpn_api.api;

class AppleVerifyReceiptRequest {
  /* The latest Base64-encoded transaction receipt. */
  String receipt = null;
  
  String appsflyerId = null;
  AppleVerifyReceiptRequest();

  @override
  String toString() {
    return 'AppleVerifyReceiptRequest[receipt=$receipt, appsflyerId=$appsflyerId, ]';
  }

  AppleVerifyReceiptRequest.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    receipt = json['receipt'];
    appsflyerId = json['appsflyer_id'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (receipt != null)
      json['receipt'] = receipt;
    if (appsflyerId != null)
      json['appsflyer_id'] = appsflyerId;
    return json;
  }

  static List<AppleVerifyReceiptRequest> listFromJson(List<dynamic> json) {
    return json == null ? List<AppleVerifyReceiptRequest>() : json.map((value) => AppleVerifyReceiptRequest.fromJson(value)).toList();
  }

  static Map<String, AppleVerifyReceiptRequest> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, AppleVerifyReceiptRequest>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = AppleVerifyReceiptRequest.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of AppleVerifyReceiptRequest-objects as value to a dart map
  static Map<String, List<AppleVerifyReceiptRequest>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<AppleVerifyReceiptRequest>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = AppleVerifyReceiptRequest.listFromJson(value);
       });
     }
     return map;
  }
}
